@@ -1,11 +1,10 @@
 from rich.console import Console
 from rich.table import Table
+from .constants import DOT_CHAR
 
 console = Console()
 rich_print = console.print
 
-DOT_CHAR = "•"
-
 
 def newline():
     print("\n", end="")
